@@ -2,10 +2,10 @@ from abc import abstractmethod
 
 from api.handler.ILogAbleHandler import ILogAbleHandler
 from api.handler.script.ICacheAbleScript import ICacheAbleScript
-from api.handler.script.IKillableScript import IKillableScript
+from api.handler.IKillable import IKillable
 
 
-class ISimpleScriptCrawl(IKillableScript,ILogAbleHandler,ICacheAbleScript):
+class ISimpleScriptCrawl(IKillable, ILogAbleHandler, ICacheAbleScript):
 
     """
     Python脚本式的Crawl的基类
@@ -16,4 +16,11 @@ class ISimpleScriptCrawl(IKillableScript,ILogAbleHandler,ICacheAbleScript):
         """
         抓取的业务逻辑
         :return: 返回一个 OutputWrapper的 数组
-        """
\ No newline at end of file
+        """
+
+    def is_killed(self)->bool:
+        """
+        判断是否杀掉了
+        :return:
+        """
+        return False
\ No newline at end of file
